from typing import (
    Any,
    Dict,
    Optional,
    Tuple,
)

import requests


SLIDO_API_URL_BASE = "https://app.sli.do/api/v0.5/"


class SlidoClient:
    def __init__(
        self, event_hash: str, auth_token: str, api_base: Optional[str] = None
    ):
        if api_base is None:
            self.api_base = SLIDO_API_URL_BASE
        else:
            self.api_base = api_base

        self.session = self._create_session(auth_token)
        self.event_uuid, self.event_id, self.event_section_id = self._get_event_data(
            event_hash
        )

    def _create_session(self, token: str) -> requests.Session:
        session = requests.Session()
        session.headers["authorization"] = f"Bearer {token}"
        return session

    def _get_event_data(self, event_hash: str) -> Tuple[str, int, int]:
        event_uuid = self.session.get(
            self.api_base + "events", params={"hash": event_hash},
        ).json()[0]["uuid"]
        event_data = self.session.get(self.api_base + f"events/{event_uuid}",).json()
        event_id = event_data["event_id"]
        event_section_id = event_data["sections"][0]["event_section_id"]
        return event_uuid, event_id, event_section_id

    def send_question(self, text: str) -> Dict[str, Any]:
        response = self.session.post(
            self.api_base + f"/events/{self.event_uuid}/questions",
            json={
                "event_id": self.event_id,
                "event_section_id": self.event_section_id,
                "is_anonymous": True,
                "labels": [],
                "media_ids": [],
                "path": "/questions",
                "text": text,
            },
        )
        response.raise_for_status()
        return response.json()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['curious_slido']

package_data = \
{'': ['*']}

install_requires = \
['requests>=2.23.0,<3.0.0']

setup_kwargs = {
    'name': 'curious-slido',
    'version': '0.1.0',
    'description': 'Sends question to a sli.do event',
    'long_description': "# curious-slido\n\nSends your questions to a [sli.do](https://sli.do) event\n\n## How to install\n\n```\npip install curious-slido \n```\n\n## How to use\n\n```python\nfrom curious_slido import SlidoClient\n\n# You can grab it from URL with event, for example\n# https://app.sli.do/event/abcd1234/live/questions -> event_hash = 'abcd1234'\nevent_hash = 'abcd1234'\n\n# You can grab it from cookie Slido.EventAuthTokens (part after comma) or from \n# any api request: \n# Developer Tools -> Network -> (request to api.sli.do) -> Headers -> Request headers -> authorization (part after `Bearer`)\nauth_token = 'longlonglongstring'\n\nslido_client = SlidoClient(event_hash=event_hash, auth_token=auth_token)\nslido_client.send_question('Your question')\n```",
    'author': 'Dima Boger',
    'author_email': 'kotvberloge@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/b0g3r/curious-slido',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
